@@ -4,10 +4,6 @@
 # Licence GPL v3
  
 
-if (!isGeneric("boxplot")) {
-	setGeneric("boxplot", function(x, ...)
-		standardGeneric("boxplot"))
-}
 
 setMethod('boxplot', signature(x='RasterStackBrick'), 
 	function(x, maxpixels=100000, ...) {
@@ -17,7 +13,7 @@ setMethod('boxplot', signature(x='RasterStackBrick'),
 			x <- getValues(x)
 		} else {
 			warning('taking a sample of ', maxpixels, ' cells')
-			x = sampleRegular(x, maxpixels, useGDAL=TRUE)
+			x <- sampleRegular(x, maxpixels, useGDAL=TRUE)
 		}	
 		colnames(x) <- cn
 		boxplot(x, ...)
@@ -39,14 +35,18 @@ setMethod('boxplot', signature(x='RasterLayer'),
 			colnames(x) <- cn
 			boxplot(x, ...)
 		} else {
-			s <- stack(x,y)
-			if ( canProcessInMemory(x)) {
+			s <- stack(x, y)
+			if ( canProcessInMemory(s)) {
 				s <- getValues(s)
 			} else {
 				warning('taking a sample of ', maxpixels, ' cells')
 				s <- sampleRegular(s, maxpixels, useGDAL=TRUE)
 			}	
 			cn <- colnames(s)
+			if (is.null(cn)) { #apparently this can happen. 
+				cn <- c('layer1', 'layer2')
+				colnames(s) <- cn
+			}
 			f <- as.formula(paste(cn[1], '~', cn[2]))
 			boxplot(f, data=s, ...)
 		}	
