@@ -6,6 +6,7 @@
 
 projectExtent <- function(object, crs) {
 	.requireRgdal()
+	use_proj6 <- .useproj6()
 	
 	object <- raster(object)
 	dm <- oldm <- dim(object)
@@ -14,14 +15,21 @@ projectExtent <- function(object, crs) {
 	dm[1] <- max(10, dm[1])
 	dm[2] <- max(10, dm[2])
 	dim(object) <- dm
-	
-	methods::validObject(projection(object, asText=FALSE))
-	methods::validObject(projection(crs, asText=FALSE))
-	projfrom <- projection(object)
-	projto <- projection(crs)
-	
-	
-	
+	pfrom <- .getCRS(object)
+	pto <- .getCRS(crs)
+	if (use_proj6) {
+		projfrom <- wkt(pfrom)
+		projto <- wkt(pto)
+		if (is.null(projfrom) || is.null(projto)) {
+			use_proj6 = FALSE
+			projfrom <- pfrom
+			projto <- pto
+		}
+	} else {
+		projfrom <- proj4string(pfrom)
+		projto <- proj4string(pto)
+	}
+
 #	rs <- res(object)
 #	xmn <- object@extent@xmin - 0.5 * rs[1]
 #	xmx <- object@extent@xmax + 0.5 * rs[1]
@@ -72,7 +80,11 @@ projectExtent <- function(object, crs) {
 	
 	}
 	
-	res <- rgdal::rawTransform( projfrom, projto, nrow(xy), xy[,1], xy[,2] )
+	if (use_proj6) {
+		res <- rgdal::rawTransform( projfrom, projto, nrow(xy), xy[,1], xy[,2], wkt=use_proj6)	
+	} else {
+		res <- rgdal::rawTransform( projfrom, projto, nrow(xy), xy[,1], xy[,2])		
+	}
 	
 	x <- res[[1]]
 	y <- res[[2]]
@@ -100,7 +112,7 @@ projectExtent <- function(object, crs) {
 }
 
 
-.computeRes <- function(obj, crs) {
+.computeRes <- function(obj, crs, proj6) {
 
 	x <- xmin(obj) + 0.5 * (xmax(obj) - xmin(obj))
 	y <- ymin(obj) + 0.5 * (ymax(obj) - ymin(obj))
@@ -110,7 +122,15 @@ projectExtent <- function(object, crs) {
 	y1 <- y - 0.5 * res[2]
 	y2 <- y + 0.5 * res[2]
 	xy <- cbind(c(x1, x2, x, x), c(y, y, y1, y2))
-	pXY <- rgdal::rawTransform( projection(obj), crs, nrow(xy), xy[,1], xy[,2] )
+	fromcrs <- .getCRS(obj)
+	if (proj6) {
+		fromcrs <- wkt(fromcrs)
+		pXY <- rgdal::rawTransform(fromcrs, crs, nrow(xy), xy[,1], xy[,2], wkt=proj6)
+	} else {
+		fromcrs <- proj4string(fromcrs)	
+		pXY <- rgdal::rawTransform(fromcrs, crs, nrow(xy), xy[,1], xy[,2])
+	}
+	
 	pXY <- cbind(pXY[[1]], pXY[[2]])
 	out <- c((pXY[2,1] - pXY[1,1]), (pXY[4,2] - pXY[3,2]))
 	if (any(is.na(out))) {
@@ -129,7 +149,7 @@ projectExtent <- function(object, crs) {
 .getAlignedRaster <- function(x,y) {
 	x <- raster(x)
 	y <- raster(y)
-	p <- projectRaster(x, crs=projection(y))
+	p <- projectRaster(x, crs=.getCRS(y))
 	m <- merge(extent(y), extent(p))
 	rx <- extend(y, m)
 	crop(rx, p)
@@ -139,25 +159,55 @@ projectExtent <- function(object, crs) {
 projectRaster <- function(from, to, res, crs, method="bilinear", alignOnly=FALSE, over=FALSE, filename="", ...)  {
 
 	.requireRgdal()
+	use_proj6 <- .useproj6()
 
-	methods::validObject( projection(from, asText=FALSE) )
-	projfrom <- projection(from)
+	projfrom <- .getCRS(from)
 	if (is.na(projfrom)) { 
 		stop("input projection is NA") 
 	}
+	if (use_proj6) {
+		if (is.null(wkt(projfrom))) {
+			use_proj6 = FALSE
+		}
+	}
+	
 	lonlat <- isLonLat(projfrom)
 	
 	if (missing(to)) {
 		if (missing(crs)) {
-			stop("'crs' argument is missing.")
+			stop("both 'to' and 'crs' arguments are missing.")
+		}
+		projto <- .getCRS(crs)
+		if (use_proj6) {
+			if (is.null(wkt(projto))) {
+				use_proj6 = FALSE
+			}
+		}
+		#compareCRS(projfrom, projto)
+		if (use_proj6) {
+			if (rgdal::compare_CRS(projto, projfrom)["strict"]) {
+				warning("input and ouput crs are the same")
+				#return(from) 
+			}
+			projfrom <- wkt(projfrom)
+		} else {
+			if (proj4string(projto) == proj4string(projfrom)) {
+				warning("input and ouput crs are the same")
+			}
+			projfrom <- proj4string(projfrom)
 		}
-		projto <- projection(crs)
 		to <- projectExtent(from, projto)
+		to@crs <- projto
+
+		if (use_proj6) {
+			projto <- wkt(projto)
+		} else {
+			projto <- proj4string(projto)		
+		}
 		if (missing(res)) {
-			res <- .computeRes(from, projto)
+			res <- .computeRes(from, projto, use_proj6)
 		}
 		res(to) <- res
-		projection(to) <- crs
 
 		# add some cells to capture curvature
 		e <- extent(to)
@@ -175,10 +225,22 @@ projectRaster <- function(from, to, res, crs, method="bilinear", alignOnly=FALSE
 		}
 		to <- extend(to, e)
 	} else {
-		projto <- projection(to)
+	
+		projto <-.getCRS(to)
 		if (is.na(projto)) { 
 			stop("output projection is NA") 
 		} 
+		if (use_proj6) {
+			if (rgdal::compare_CRS(projto, projfrom)["strict"]) {
+				warning("input and ouput crs are the same")
+			}
+			projfrom <- wkt(projfrom)
+		} else {
+			if (proj4string(projto) == proj4string(projfrom)) {
+				warning("input and ouput crs are the same")
+			}
+			projfrom = proj4string(projfrom)
+		}
 		
 		e <- extent( projectExtent(from, projto) )
 		add <- min(10, min(dim(to)[1:2])/10) * max(raster::res(to))
@@ -186,22 +248,27 @@ projectRaster <- function(from, to, res, crs, method="bilinear", alignOnly=FALSE
 		e@ymax <- e@ymax + add
 		e@xmin <- e@xmin - add
 		e@xmax <- e@xmax + add
-		if (!is.character(projto)) projto <- projto@projargs
-		if (substr(projto, 1, 13) == "+proj=longlat") {
+		if (isLonLat(projto)) {
 			e@xmin <- max(-180, e@xmin)
 			e@xmax <- min(180, e@xmax)
 			e@ymin <- max(-90, e@ymin)
 			e@ymax <- min(90, e@ymax)
-		}	
+		}
+
+		if (use_proj6) {
+			projto <- wkt(projto)
+		} else {
+			projto <- proj4string(projto)
+		}
 	}
 	
 	methods::validObject(to)
-	methods::validObject(projection(to, asText=FALSE))
+	methods::validObject(.getCRS((to)))
 
 	#if (identical(projfrom, projto)) {
 	#	warning('projections of "from" and "to" are the same')
 	#}	
-	if (lonlat & over) {
+	if ((!use_proj6) & lonlat & over) {
 		projto_int <- paste(projto, "+over")
 	} else {
 		projto_int <- projto	
@@ -211,7 +278,7 @@ projectRaster <- function(from, to, res, crs, method="bilinear", alignOnly=FALSE
 		to <- .getAlignedRaster(to, from)
 	}
 	
-#	pbb <- projectExtent(to, projection(from))
+#	pbb <- projectExtent(to,.getCRS(from))
 #	bb <- intersect(extent(pbb), extent(from))
 #	methods::validObject(bb)
 
@@ -271,7 +338,12 @@ projectRaster <- function(from, to, res, crs, method="bilinear", alignOnly=FALSE
 			v <- matrix(nrow=length(cells), ncol=nl)
 			if (nrow(xy) > 0) {
 				ci <- match(cellFromXY(to, xy), cells)
-				xy <- rgdal::rawTransform(projto_int, projfrom, nrow(xy), xy[,1], xy[,2])
+				if (use_proj6) {
+					xy <- rgdal::rawTransform(projto_int, projfrom, nrow(xy), xy[,1], xy[,2], wkt=use_proj6)
+				} else {
+					xy <- rgdal::rawTransform(projto_int, projfrom, nrow(xy), xy[,1], xy[,2])				
+				}
+			
 				xy <- cbind(xy[[1]], xy[[2]])
 				v[ci, ] <- .xyValues(from, xy, method=method)
 			} 
@@ -343,7 +415,11 @@ projectRaster <- function(from, to, res, crs, method="bilinear", alignOnly=FALSE
 			xy <- coordinates(to) 
 			xy <- subset(xy, xy[,1] > e@xmin & xy[,1] < e@xmax)
 			cells <- cellFromXY(to, xy)
-			xy <- rgdal::rawTransform( projto_int, projfrom, nrow(xy), xy[,1], xy[,2] )
+			if (use_proj6) {
+				xy <- rgdal::rawTransform( projto_int, projfrom, nrow(xy), xy[,1], xy[,2], wkt=use_proj6 )
+			} else {
+				xy <- rgdal::rawTransform( projto_int, projfrom, nrow(xy), xy[,1], xy[,2])
+			}
 			xy <- cbind(xy[[1]], xy[[2]])
 			to[cells] <- .xyValues(from, xy, method=method)
 			
@@ -363,7 +439,12 @@ projectRaster <- function(from, to, res, crs, method="bilinear", alignOnly=FALSE
 				xy <- subset(xy, xy[,1] > e@xmin & xy[,1] < e@xmax)
 				if (nrow(xy) > 0) {
 					ci <- match(cellFromXY(to, xy), cells)
-					xy <- rgdal::rawTransform( projto_int, projfrom, nrow(xy), xy[,1], xy[,2] )
+
+					if (use_proj6) {
+						xy <- rgdal::rawTransform( projto_int, projfrom, nrow(xy), xy[,1], xy[,2], wkt=use_proj6 )
+					} else {
+						xy <- rgdal::rawTransform( projto_int, projfrom, nrow(xy), xy[,1], xy[,2])
+					}
 					xy <- cbind(xy[[1]], xy[[2]])
 					v <- matrix(nrow=length(cells), ncol=nl)
 					v[ci, ] <- .xyValues(from, xy, method=method)
